<?php
namespace Aura\Framework\Web\Controller;

use Aura\Framework\Inflect;
use Aura\Framework\Signal\Manager as SignalManager;
use Aura\Framework\Web\Renderer\AuraViewTwoStep as Renderer;
use Aura\Router\Map as RouterMap;
use Aura\Router\RouteFactory;
use Aura\Signal\HandlerFactory;
use Aura\Signal\ResultCollection;
use Aura\Signal\ResultFactory;
use Aura\View\EscaperFactory;
use Aura\View\FormatTypes;
use Aura\View\HelperLocator;
use Aura\View\Template;
use Aura\View\TemplateFinder;
use Aura\View\TwoStep;
use Aura\Web\Context;
use Aura\Web\Response;

/**
 * Test class for Page.
 * Generated by PHPUnit on 2011-05-27 at 11:01:03.
 */
abstract class AbstractPageTest extends \PHPUnit_Framework_TestCase
{
    protected $page_name;

    protected function newPage($params = [])
    {
        // context
        $context            = new Context($GLOBALS);
        
        // web response dto
        $response           = new Response;
        
        // signal manager
        $signal             = new SignalManager(new HandlerFactory, new ResultFactory, new ResultCollection);
        
        // two step view
        $escaper_factory    = new EscaperFactory;
        $template_finder    = new TemplateFinder;
        $helper_locator     = new HelperLocator;
        $template           = new Template($escaper_factory, $template_finder, $helper_locator);
        $format_types       = new FormatTypes;
        $twostep            = new TwoStep($template, $format_types);
        
        // renderer
        $renderer           = new Renderer($twostep, new Inflect);
        
        // page
        $class = "\Aura\Framework\Web\\{$this->page_name}\Page";
        $page = new $class(
            $context,
            $response,
            $signal,
            $renderer,
            $params
        );
        
        // add router to page
        $router = new RouterMap(new RouteFactory);
        $page->setRouter($router);
        
        // done!
        return $page;
    }
}
